@@ -8,7 +8,9 @@ use warnings;
 use Carp;
 use base qw{ Exporter };
 
-our $VERSION = '0.017_01';
+our $VERSION = '0.018_01';
+
+no warnings qw{ once };	# For older Perls.
 
 our @CARP_NOT = qw{
     PPIx::QuoteLike
@@ -25,6 +27,8 @@ our @CARP_NOT = qw{
     PPIx::QuoteLike::Utils
 };
 
+use warnings qw{ once };
+
 our @EXPORT_OK = qw{
     ARRAY_REF
     MINIMUM_PERL
